pygeodesy.auxilats.auxily

Package pygeodesy :: Package auxilats :: Module auxily |
[frames] | no frames]

# Module auxily

(INTERNAL) Auxiliary latitudes' classes, constants and functions.

Class AuxAngle transcoded to Python from Karney's C++ class AuxAngle in GeographicLib version 2.2+.

Copyright (C) Charles Karney (2022-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 25.08.31

Variables
| Aux = `Aux()`